@@ -21,6 +21,7 @@ import datetime
 from google.cloud._helpers import UTC
 from google.cloud._helpers import _date_from_iso8601_date
 from google.cloud._helpers import _datetime_from_microseconds
+from google.cloud._helpers import _microseconds_from_datetime
 from google.cloud._helpers import _RFC3339_NO_FRACTION
 from google.cloud._helpers import _time_from_iso8601_time_naive
 from google.cloud._helpers import _to_bytes
@@ -122,82 +123,11 @@ _CELLDATA_FROM_JSON = {
 }
 
 
-def _int_to_json(value):
-    """Coerce 'value' to an JSON-compatible representation."""
-    if isinstance(value, int):
-        value = str(value)
-    return value
-
-
-def _float_to_json(value):
-    """Coerce 'value' to an JSON-compatible representation."""
-    return value
-
-
-def _bool_to_json(value):
-    """Coerce 'value' to an JSON-compatible representation."""
-    if isinstance(value, bool):
-        value = 'true' if value else 'false'
-    return value
-
-
-def _bytes_to_json(value):
-    """Coerce 'value' to an JSON-compatible representation."""
-    if isinstance(value, bytes):
-        value = base64.standard_b64encode(value).decode('ascii')
-    return value
-
-
-def _timestamp_to_json(value):
-    """Coerce 'value' to an JSON-compatible representation."""
-    if isinstance(value, datetime.datetime):
-        if value.tzinfo not in (None, UTC):
-            # Convert to UTC and remove the time zone info.
-            value = value.replace(tzinfo=None) - value.utcoffset()
-        value = '%s %s+00:00' % (
-            value.date().isoformat(), value.time().isoformat())
-    return value
-
-
-def _datetime_to_json(value):
-    """Coerce 'value' to an JSON-compatible representation."""
-    if isinstance(value, datetime.datetime):
-        value = value.strftime(_RFC3339_MICROS_NO_ZULU)
-    return value
-
-
-def _date_to_json(value):
-    """Coerce 'value' to an JSON-compatible representation."""
-    if isinstance(value, datetime.date):
-        value = value.isoformat()
-    return value
-
-
-def _time_to_json(value):
-    """Coerce 'value' to an JSON-compatible representation."""
-    if isinstance(value, datetime.time):
-        value = value.isoformat()
-    return value
-
-
-_SCALAR_VALUE_TO_JSON = {
-    'INTEGER': _int_to_json,
-    'INT64': _int_to_json,
-    'FLOAT': _float_to_json,
-    'FLOAT64': _float_to_json,
-    'BOOLEAN': _bool_to_json,
-    'BOOL': _bool_to_json,
-    'BYTES': _bytes_to_json,
-    'TIMESTAMP': _timestamp_to_json,
-    'DATETIME': _datetime_to_json,
-    'DATE': _date_to_json,
-    'TIME': _time_to_json,
-}
-
-
 def _row_from_json(row, schema):
     """Convert JSON row data to row with appropriate types.
 
+    Note:  ``row['f']`` and ``schema`` are presumed to be of the same length.
+
     :type row: dict
     :param row: A JSON response row to be converted.
 
@@ -225,6 +155,98 @@ def _rows_from_json(rows, schema):
     return [_row_from_json(row, schema) for row in rows]
 
 
+def _int_to_json(value):
+    """Coerce 'value' to an JSON-compatible representation."""
+    if isinstance(value, int):
+        value = str(value)
+    return value
+
+
+def _float_to_json(value):
+    """Coerce 'value' to an JSON-compatible representation."""
+    return value
+
+
+def _bool_to_json(value):
+    """Coerce 'value' to an JSON-compatible representation."""
+    if isinstance(value, bool):
+        value = 'true' if value else 'false'
+    return value
+
+
+def _bytes_to_json(value):
+    """Coerce 'value' to an JSON-compatible representation."""
+    if isinstance(value, bytes):
+        value = base64.standard_b64encode(value).decode('ascii')
+    return value
+
+
+def _timestamp_to_json_parameter(value):
+    """Coerce 'value' to an JSON-compatible representation.
+
+    This version returns the string representation used in query parameters.
+    """
+    if isinstance(value, datetime.datetime):
+        if value.tzinfo not in (None, UTC):
+            # Convert to UTC and remove the time zone info.
+            value = value.replace(tzinfo=None) - value.utcoffset()
+        value = '%s %s+00:00' % (
+            value.date().isoformat(), value.time().isoformat())
+    return value
+
+
+def _timestamp_to_json_row(value):
+    """Coerce 'value' to an JSON-compatible representation.
+
+    This version returns floating-point seconds value used in row data.
+    """
+    if isinstance(value, datetime.datetime):
+        value = _microseconds_from_datetime(value) * 1e-6
+    return value
+
+
+def _datetime_to_json(value):
+    """Coerce 'value' to an JSON-compatible representation."""
+    if isinstance(value, datetime.datetime):
+        value = value.strftime(_RFC3339_MICROS_NO_ZULU)
+    return value
+
+
+def _date_to_json(value):
+    """Coerce 'value' to an JSON-compatible representation."""
+    if isinstance(value, datetime.date):
+        value = value.isoformat()
+    return value
+
+
+def _time_to_json(value):
+    """Coerce 'value' to an JSON-compatible representation."""
+    if isinstance(value, datetime.time):
+        value = value.isoformat()
+    return value
+
+
+# Converters used for scalar values marshalled as row data.
+_SCALAR_VALUE_TO_JSON_ROW = {
+    'INTEGER': _int_to_json,
+    'INT64': _int_to_json,
+    'FLOAT': _float_to_json,
+    'FLOAT64': _float_to_json,
+    'BOOLEAN': _bool_to_json,
+    'BOOL': _bool_to_json,
+    'BYTES': _bytes_to_json,
+    'TIMESTAMP': _timestamp_to_json_row,
+    'DATETIME': _datetime_to_json,
+    'DATE': _date_to_json,
+    'TIME': _time_to_json,
+}
+
+
+# Converters used for scalar values marshalled as query parameters.
+_SCALAR_VALUE_TO_JSON_PARAM = _SCALAR_VALUE_TO_JSON_ROW.copy()
+_SCALAR_VALUE_TO_JSON_PARAM['TIMESTAMP'] = _timestamp_to_json_parameter
+
+
 class _ConfigurationProperty(object):
     """Base property implementation.
 
@@ -296,7 +318,7 @@ class _EnumProperty(_ConfigurationProperty):
         :raises: ValueError if value is not allowed.
         """
         if value not in self.ALLOWED:
-            raise ValueError('Pass one of: %s' ', '.join(self.ALLOWED))
+            raise ValueError('Pass one of: %s' % ', '.join(self.ALLOWED))
 
 
 class UDFResource(object):
@@ -342,7 +364,7 @@ class AbstractQueryParameter(object):
     """
     @classmethod
     def from_api_repr(cls, resource):
-        """Factory: construct paramter from JSON resource.
+        """Factory: construct parameter from JSON resource.
 
         :type resource: dict
         :param resource: JSON mapping of parameter
@@ -364,7 +386,7 @@ class ScalarQueryParameter(AbstractQueryParameter):
 
     :type name: str or None
     :param name: Parameter name, used via ``@foo`` syntax.  If None, the
-                 paramter can only be addressed via position (``?``).
+                 parameter can only be addressed via position (``?``).
 
     :type type_: str
     :param type_: name of parameter type.  One of 'STRING', 'INT64',
@@ -381,11 +403,11 @@ class ScalarQueryParameter(AbstractQueryParameter):
 
     @classmethod
     def positional(cls, type_, value):
-        """Factory for positional paramters.
+        """Factory for positional paramater.
 
         :type type_: str
         :param type_:
-            name of paramter type.  One of 'STRING', 'INT64',
+            name of parameter type.  One of 'STRING', 'INT64',
             'FLOAT64', 'BOOL', 'TIMESTAMP', 'DATETIME', or 'DATE'.
 
         :type value: str, int, float, bool, :class:`datetime.datetime`, or
@@ -399,7 +421,7 @@ class ScalarQueryParameter(AbstractQueryParameter):
 
     @classmethod
     def from_api_repr(cls, resource):
-        """Factory: construct paramter from JSON resource.
+        """Factory: construct parameter from JSON resource.
 
         :type resource: dict
         :param resource: JSON mapping of parameter
@@ -420,7 +442,7 @@ class ScalarQueryParameter(AbstractQueryParameter):
         :returns: JSON mapping
         """
         value = self.value
-        converter = _SCALAR_VALUE_TO_JSON.get(self.type_)
+        converter = _SCALAR_VALUE_TO_JSON_PARAM.get(self.type_)
         if converter is not None:
             value = converter(value)
         resource = {
@@ -441,7 +463,7 @@ class ArrayQueryParameter(AbstractQueryParameter):
 
     :type name: str or None
     :param name: Parameter name, used via ``@foo`` syntax.  If None, the
-                 paramter can only be addressed via position (``?``).
+                 parameter can only be addressed via position (``?``).
 
     :type array_type: str
     :param array_type:
@@ -458,7 +480,7 @@ class ArrayQueryParameter(AbstractQueryParameter):
 
     @classmethod
     def positional(cls, array_type, values):
-        """Factory for positional paramters.
+        """Factory for positional parameters.
 
         :type array_type: str
         :param array_type:
@@ -475,7 +497,7 @@ class ArrayQueryParameter(AbstractQueryParameter):
 
     @classmethod
     def from_api_repr(cls, resource):
-        """Factory: construct paramter from JSON resource.
+        """Factory: construct parameter from JSON resource.
 
         :type resource: dict
         :param resource: JSON mapping of parameter
@@ -506,7 +528,7 @@ class ArrayQueryParameter(AbstractQueryParameter):
             a_values = [repr_['parameterValue'] for repr_ in reprs]
         else:
             a_type = {'type': self.array_type}
-            converter = _SCALAR_VALUE_TO_JSON.get(self.array_type)
+            converter = _SCALAR_VALUE_TO_JSON_PARAM.get(self.array_type)
             if converter is not None:
                 values = [converter(value) for value in values]
             a_values = [{'value': value} for value in values]
@@ -529,7 +551,7 @@ class StructQueryParameter(AbstractQueryParameter):
 
     :type name: str or None
     :param name: Parameter name, used via ``@foo`` syntax.  If None, the
-                 paramter can only be addressed via position (``?``).
+                 parameter can only be addressed via position (``?``).
 
     :type sub_params: tuple of :class:`ScalarQueryParameter`
     :param sub_params: the sub-parameters for the struct
@@ -551,7 +573,7 @@ class StructQueryParameter(AbstractQueryParameter):
 
     @classmethod
     def positional(cls, *sub_params):
-        """Factory for positional paramters.
+        """Factory for positional parameters.
 
         :type sub_params: tuple of :class:`ScalarQueryParameter`
         :param sub_params: the sub-parameters for the struct
@@ -563,7 +585,7 @@ class StructQueryParameter(AbstractQueryParameter):
 
     @classmethod
     def from_api_repr(cls, resource):
-        """Factory: construct paramter from JSON resource.
+        """Factory: construct parameter from JSON resource.
 
         :type resource: dict
         :param resource: JSON mapping of parameter
@@ -600,7 +622,7 @@ class StructQueryParameter(AbstractQueryParameter):
                 values[name] = repr_['parameterValue']
             else:
                 s_types[name] = {'name': name, 'type': {'type': type_}}
-                converter = _SCALAR_VALUE_TO_JSON.get(type_)
+                converter = _SCALAR_VALUE_TO_JSON_PARAM.get(type_)
                 if converter is not None:
                     value = converter(value)
                 values[name] = {'value': value}
@@ -635,7 +657,7 @@ class QueryParametersProperty(object):
         :rtype: list of instances of classes derived from
                 :class:`AbstractQueryParameter`.
         :returns: the descriptor, if accessed via the class, or the instance's
-                  query paramters.
+                  query parameters.
         """
         if instance is None:
             return self
@@ -656,3 +678,44 @@ class QueryParametersProperty(object):
             raise ValueError(
                 "query parameters must be derived from AbstractQueryParameter")
         instance._query_parameters = tuple(value)
+
+
+def _item_to_row(iterator, resource):
+    """Convert a JSON row to the native object.
+
+    .. note::
+
+        This assumes that the ``schema`` attribute has been
+        added to the iterator after being created, which
+        should be done by the caller.
+
+    :type iterator: :class:`~google.cloud.iterator.Iterator`
+    :param iterator: The iterator that is currently in use.
+
+    :type resource: dict
+    :param resource: An item to be converted to a row.
+
+    :rtype: tuple
+    :returns: The next row in the page.
+    """
+    return _row_from_json(resource, iterator.schema)
+
+
+# pylint: disable=unused-argument
+def _rows_page_start(iterator, page, response):
+    """Grab total rows when :class:`~google.cloud.iterator.Page` starts.
+
+    :type iterator: :class:`~google.cloud.iterator.Iterator`
+    :param iterator: The iterator that is currently in use.
+
+    :type page: :class:`~google.cloud.iterator.Page`
+    :param page: The page that was just created.
+
+    :type response: dict
+    :param response: The JSON API response for a page of rows in a table.
+    """
+    total_rows = response.get('totalRows')
+    if total_rows is not None:
+        total_rows = int(total_rows)
+    iterator.total_rows = total_rows
+# pylint: enable=unused-argument
