@@ -301,7 +301,7 @@ class _AsyncJob(_BaseJob):
     def begin(self, client=None):
         """API call:  begin the job via a POST request
 
-        See:
+        See
         https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/insert
 
         :type client: :class:`~google.cloud.bigquery.client.Client` or
@@ -497,57 +497,57 @@ class LoadTableFromStorageJob(_AsyncJob):
             return int(statistics['load']['outputRows'])
 
     allow_jagged_rows = _TypedProperty('allow_jagged_rows', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.load.allowJaggedRows
     """
 
     allow_quoted_newlines = _TypedProperty('allow_quoted_newlines', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.load.allowQuotedNewlines
     """
 
     create_disposition = CreateDisposition('create_disposition')
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.load.createDisposition
     """
 
     encoding = Encoding('encoding')
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.load.encoding
     """
 
     field_delimiter = _TypedProperty('field_delimiter', six.string_types)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.load.fieldDelimiter
     """
 
     ignore_unknown_values = _TypedProperty('ignore_unknown_values', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.load.ignoreUnknownValues
     """
 
     max_bad_records = _TypedProperty('max_bad_records', six.integer_types)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.load.maxBadRecords
     """
 
     quote_character = _TypedProperty('quote_character', six.string_types)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.load.quote
     """
 
     skip_leading_rows = _TypedProperty('skip_leading_rows', six.integer_types)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.load.skipLeadingRows
     """
 
     source_format = SourceFormat('source_format')
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.load.sourceFormat
     """
 
     write_disposition = WriteDisposition('write_disposition')
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.load.writeDisposition
     """
 
@@ -672,12 +672,12 @@ class CopyJob(_AsyncJob):
         self._configuration = _CopyConfiguration()
 
     create_disposition = CreateDisposition('create_disposition')
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.copy.createDisposition
     """
 
     write_disposition = WriteDisposition('write_disposition')
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.copy.writeDisposition
     """
 
@@ -795,22 +795,22 @@ class ExtractTableToStorageJob(_AsyncJob):
         self._configuration = _ExtractConfiguration()
 
     compression = Compression('compression')
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.extract.compression
     """
 
     destination_format = DestinationFormat('destination_format')
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.extract.destinationFormat
     """
 
     field_delimiter = _TypedProperty('field_delimiter', six.string_types)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.extract.fieldDelimiter
     """
 
     print_header = _TypedProperty('print_header', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.extract.printHeader
     """
 
@@ -936,32 +936,32 @@ class QueryJob(_AsyncJob):
         self._configuration = _AsyncQueryConfiguration()
 
     allow_large_results = _TypedProperty('allow_large_results', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.query.allowLargeResults
     """
 
     create_disposition = CreateDisposition('create_disposition')
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.query.createDisposition
     """
 
     default_dataset = _TypedProperty('default_dataset', Dataset)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.query.defaultDataset
     """
 
     destination = _TypedProperty('destination', Table)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.query.destinationTable
     """
 
     flatten_results = _TypedProperty('flatten_results', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.query.flattenResults
     """
 
     priority = QueryPriority('priority')
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.query.priority
     """
 
@@ -970,34 +970,34 @@ class QueryJob(_AsyncJob):
     udf_resources = UDFResourcesProperty()
 
     use_query_cache = _TypedProperty('use_query_cache', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.query.useQueryCache
     """
 
     use_legacy_sql = _TypedProperty('use_legacy_sql', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/\
     reference/v2/jobs#configuration.query.useLegacySql
     """
 
     dry_run = _TypedProperty('dry_run', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/\
     reference/rest/v2/jobs#configuration.dryRun
     """
 
     write_disposition = WriteDisposition('write_disposition')
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.query.writeDisposition
     """
 
     maximum_billing_tier = _TypedProperty('maximum_billing_tier', int)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.query.maximumBillingTier
     """
 
     maximum_bytes_billed = _TypedProperty('maximum_bytes_billed', int)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs#configuration.query.maximumBytesBilled
     """
 
