@@ -16,6 +16,7 @@
 
 import six
 
+from google.cloud.iterator import HTTPIterator
 from google.cloud.bigquery._helpers import _TypedProperty
 from google.cloud.bigquery._helpers import _rows_from_json
 from google.cloud.bigquery.dataset import Dataset
@@ -23,6 +24,8 @@ from google.cloud.bigquery.job import QueryJob
 from google.cloud.bigquery.table import _parse_schema_resource
 from google.cloud.bigquery._helpers import QueryParametersProperty
 from google.cloud.bigquery._helpers import UDFResourcesProperty
+from google.cloud.bigquery._helpers import _item_to_row
+from google.cloud.bigquery._helpers import _rows_page_start
 
 
 class _SyncQueryConfiguration(object):
@@ -123,7 +126,7 @@ class QueryResults(object):
     def cache_hit(self):
         """Query results served from cache.
 
-        See:
+        See
         https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#cacheHit
 
         :rtype: bool or ``NoneType``
@@ -136,7 +139,7 @@ class QueryResults(object):
     def complete(self):
         """Server completed query.
 
-        See:
+        See
         https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#jobComplete
 
         :rtype: bool or ``NoneType``
@@ -149,7 +152,7 @@ class QueryResults(object):
     def errors(self):
         """Errors generated by the query.
 
-        See:
+        See
         https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#errors
 
         :rtype: list of mapping, or ``NoneType``
@@ -162,7 +165,7 @@ class QueryResults(object):
     def name(self):
         """Job name, generated by the back-end.
 
-        See:
+        See
         https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#jobReference
 
         :rtype: list of mapping, or ``NoneType``
@@ -190,7 +193,7 @@ class QueryResults(object):
     def page_token(self):
         """Token for fetching next bach of results.
 
-        See:
+        See
         https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#pageToken
 
         :rtype: str, or ``NoneType``
@@ -202,7 +205,7 @@ class QueryResults(object):
     def total_rows(self):
         """Total number of rows returned by the query.
 
-        See:
+        See
         https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#totalRows
 
         :rtype: int, or ``NoneType``
@@ -216,7 +219,7 @@ class QueryResults(object):
     def total_bytes_processed(self):
         """Total number of bytes processed by the query.
 
-        See:
+        See
         https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#totalBytesProcessed
 
         :rtype: int, or ``NoneType``
@@ -226,11 +229,25 @@ class QueryResults(object):
         if total_bytes_processed is not None:
             return int(total_bytes_processed)
 
+    @property
+    def num_dml_affected_rows(self):
+        """Total number of rows affected by a DML query.
+
+        See
+        https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#numDmlAffectedRows
+
+        :rtype: int, or ``NoneType``
+        :returns: Count generated on the server (None until set by the server).
+        """
+        num_dml_affected_rows = self._properties.get('numDmlAffectedRows')
+        if num_dml_affected_rows is not None:
+            return int(num_dml_affected_rows)
+
     @property
     def rows(self):
         """Query results.
 
-        See:
+        See
         https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#rows
 
         :rtype: list of tuples of row values, or ``NoneType``
@@ -242,7 +259,7 @@ class QueryResults(object):
     def schema(self):
         """Schema for query results.
 
-        See:
+        See
         https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#schema
 
         :rtype: list of :class:`SchemaField`, or ``NoneType``
@@ -251,41 +268,41 @@ class QueryResults(object):
         return _parse_schema_resource(self._properties.get('schema', {}))
 
     default_dataset = _TypedProperty('default_dataset', Dataset)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#defaultDataset
     """
 
     dry_run = _TypedProperty('dry_run', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#dryRun
     """
 
     max_results = _TypedProperty('max_results', six.integer_types)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#maxResults
     """
 
     preserve_nulls = _TypedProperty('preserve_nulls', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#preserveNulls
     """
 
     query_parameters = QueryParametersProperty()
 
     timeout_ms = _TypedProperty('timeout_ms', six.integer_types)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#timeoutMs
     """
 
     udf_resources = UDFResourcesProperty()
 
     use_query_cache = _TypedProperty('use_query_cache', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query#useQueryCache
     """
 
     use_legacy_sql = _TypedProperty('use_legacy_sql', bool)
-    """See:
+    """See
     https://cloud.google.com/bigquery/docs/\
     reference/v2/jobs/query#useLegacySql
     """
@@ -347,7 +364,7 @@ class QueryResults(object):
     def run(self, client=None):
         """API call:  run the query via a POST request
 
-        See:
+        See
         https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/query
 
         :type client: :class:`~google.cloud.bigquery.client.Client` or
@@ -368,7 +385,7 @@ class QueryResults(object):
                    timeout_ms=None, client=None):
         """API call:  fetch a page of query result data via a GET request
 
-        See:
+        See
         https://cloud.google.com/bigquery/docs/reference/rest/v2/jobs/getQueryResults
 
         :type max_results: int
@@ -383,7 +400,14 @@ class QueryResults(object):
 
         :type timeout_ms: int
         :param timeout_ms:
-            (Optional) timeout, in milliseconds, to wait for query to complete
+            (Optional) How long to wait for the query to complete, in
+            milliseconds, before the request times out and returns. Note that
+            this is only a timeout for the request, not the query. If the query
+            takes longer to run than the timeout value, the call returns
+            without any results and with the 'jobComplete' flag set to false.
+            You can call GetQueryResults() to wait for the query to complete
+            and read the results. The default value is 10000 milliseconds (10
+            seconds).
 
         :type client: :class:`~google.cloud.bigquery.client.Client` or
                       ``NoneType``
@@ -405,12 +429,6 @@ class QueryResults(object):
         client = self._require_client(client)
         params = {}
 
-        if max_results is not None:
-            params['maxResults'] = max_results
-
-        if page_token is not None:
-            params['pageToken'] = page_token
-
         if start_index is not None:
             params['startIndex'] = start_index
 
@@ -418,15 +436,37 @@ class QueryResults(object):
             params['timeoutMs'] = timeout_ms
 
         path = '/projects/%s/queries/%s' % (self.project, self.name)
-        response = client._connection.api_request(method='GET',
-                                                  path=path,
-                                                  query_params=params)
-        self._set_properties(response)
+        iterator = HTTPIterator(client=client, path=path,
+                                item_to_value=_item_to_row,
+                                items_key='rows',
+                                page_token=page_token,
+                                max_results=max_results,
+                                page_start=_rows_page_start_query,
+                                extra_params=params)
+        iterator.query_result = self
+        # Over-ride the key used to retrieve the next page token.
+        iterator._NEXT_TOKEN = 'pageToken'
+        return iterator
 
-        total_rows = response.get('totalRows')
-        if total_rows is not None:
-            total_rows = int(total_rows)
-        page_token = response.get('pageToken')
-        rows_data = _rows_from_json(response.get('rows', ()), self.schema)
 
-        return rows_data, total_rows, page_token
+def _rows_page_start_query(iterator, page, response):
+    """Update query response when :class:`~google.cloud.iterator.Page` starts.
+
+    .. note::
+
+        This assumes that the ``query_response`` attribute has been
+        added to the iterator after being created, which
+        should be done by the caller.
+
+    :type iterator: :class:`~google.cloud.iterator.Iterator`
+    :param iterator: The iterator that is currently in use.
+
+    :type page: :class:`~google.cloud.iterator.Page`
+    :param page: The page that was just created.
+
+    :type response: dict
+    :param response: The JSON API response for a page of rows in a table.
+    """
+    iterator.query_result._set_properties(response)
+    iterator.schema = iterator.query_result.schema
+    _rows_page_start(iterator, page, response)
